A dataset containing summarized by calculating the median for dynamic functional connectivity estimates of pairwise region of interest (ROI) comparisions.
data(MLPB_output_median)A list with 3 matrices, each matrix has 5 rows and 731 columns, where rows represent subjects-level multivariate linear process bootstrapping (MLPB) estimates and columns represent median of MLPB estimates at each window.
matrix with 5 rows and 731 columns, containing median of multivariate linear process bootstrapping results between region 1 and 2 in subject-level.
matrix with 5 rows and 731 columns, containing median of multivariate linear process bootstrapping results between region 1 and 3 in subject-level.
matrix with 5 rows and 731 columns, containing median of multivariate linear process bootstrapping results between region 2 and 3 in subject-level.